@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -364,15 +364,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def create_scan_config(
         self,
-        request: web_security_scanner.CreateScanConfigRequest = None,
+        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -381,7 +378,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Creates a new ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest, dict]):
                 The request object. Request for the `CreateScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -422,7 +419,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def delete_scan_config(
         self,
-        request: web_security_scanner.DeleteScanConfigRequest = None,
+        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -432,7 +429,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         resources.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest, dict]):
                 The request object. Request for the `DeleteScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -466,7 +463,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_scan_config(
         self,
-        request: web_security_scanner.GetScanConfigRequest = None,
+        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -475,7 +472,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Gets a ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.GetScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.GetScanConfigRequest, dict]):
                 The request object. Request for the `GetScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -516,7 +513,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_scan_configs(
         self,
-        request: web_security_scanner.ListScanConfigsRequest = None,
+        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -525,7 +522,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Lists ScanConfigs under a given project.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest, dict]):
                 The request object. Request for the `ListScanConfigs`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -574,7 +571,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def update_scan_config(
         self,
-        request: web_security_scanner.UpdateScanConfigRequest = None,
+        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -584,7 +581,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         update of a ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest, dict]):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -627,7 +624,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def start_scan_run(
         self,
-        request: web_security_scanner.StartScanRunRequest = None,
+        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -636,7 +633,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Start a ScanRun according to the given ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.StartScanRunRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.StartScanRunRequest, dict]):
                 The request object. Request for the `StartScanRun`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -678,7 +675,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_scan_run(
         self,
-        request: web_security_scanner.GetScanRunRequest = None,
+        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -687,7 +684,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Gets a ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.GetScanRunRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.GetScanRunRequest, dict]):
                 The request object. Request for the `GetScanRun` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -728,7 +725,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_scan_runs(
         self,
-        request: web_security_scanner.ListScanRunsRequest = None,
+        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -738,7 +735,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         descending order of ScanRun stop time.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.ListScanRunsRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListScanRunsRequest, dict]):
                 The request object. Request for the `ListScanRuns`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -787,7 +784,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def stop_scan_run(
         self,
-        request: web_security_scanner.StopScanRunRequest = None,
+        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -796,7 +793,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Stops a ScanRun. The stopped ScanRun is returned.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.StopScanRunRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.StopScanRunRequest, dict]):
                 The request object. Request for the `StopScanRun`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -838,7 +835,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_crawled_urls(
         self,
-        request: web_security_scanner.ListCrawledUrlsRequest = None,
+        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -847,7 +844,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""List CrawledUrls under a given ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest, dict]):
                 The request object. Request for the `ListCrawledUrls`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -896,7 +893,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_finding(
         self,
-        request: web_security_scanner.GetFindingRequest = None,
+        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -905,7 +902,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Gets a Finding.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.GetFindingRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.GetFindingRequest, dict]):
                 The request object. Request for the `GetFinding` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -946,7 +943,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_findings(
         self,
-        request: web_security_scanner.ListFindingsRequest = None,
+        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -955,7 +952,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""List Findings under a given ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.ListFindingsRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListFindingsRequest, dict]):
                 The request object. Request for the `ListFindings`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1004,7 +1001,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_finding_type_stats(
         self,
-        request: web_security_scanner.ListFindingTypeStatsRequest = None,
+        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1013,7 +1010,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""List all FindingTypeStats under a given ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest, dict]):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1050,6 +1047,19 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
