@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -397,15 +397,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def create_scan_config(
         self,
-        request: web_security_scanner.CreateScanConfigRequest = None,
+        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
         *,
         parent: str = None,
         scan_config: gcw_scan_config.ScanConfig = None,
@@ -416,7 +413,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Creates a new ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.CreateScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.CreateScanConfigRequest, dict]):
                 The request object. Request for the `CreateScanConfig`
                 method.
             parent (str):
@@ -488,7 +485,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def delete_scan_config(
         self,
-        request: web_security_scanner.DeleteScanConfigRequest = None,
+        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -499,7 +496,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         resources.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.DeleteScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.DeleteScanConfigRequest, dict]):
                 The request object. Request for the `DeleteScanConfig`
                 method.
             name (str):
@@ -555,7 +552,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_scan_config(
         self,
-        request: web_security_scanner.GetScanConfigRequest = None,
+        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -565,7 +562,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Gets a ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.GetScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.GetScanConfigRequest, dict]):
                 The request object. Request for the `GetScanConfig`
                 method.
             name (str):
@@ -628,7 +625,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_scan_configs(
         self,
-        request: web_security_scanner.ListScanConfigsRequest = None,
+        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -638,7 +635,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Lists ScanConfigs under a given project.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.ListScanConfigsRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.ListScanConfigsRequest, dict]):
                 The request object. Request for the `ListScanConfigs`
                 method.
             parent (str):
@@ -708,7 +705,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def update_scan_config(
         self,
-        request: web_security_scanner.UpdateScanConfigRequest = None,
+        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
         *,
         scan_config: gcw_scan_config.ScanConfig = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -720,7 +717,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         update of a ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.UpdateScanConfigRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.UpdateScanConfigRequest, dict]):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
             scan_config (google.cloud.websecurityscanner_v1beta.types.ScanConfig):
@@ -796,7 +793,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def start_scan_run(
         self,
-        request: web_security_scanner.StartScanRunRequest = None,
+        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -806,7 +803,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Start a ScanRun according to the given ScanConfig.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.StartScanRunRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.StartScanRunRequest, dict]):
                 The request object. Request for the `StartScanRun`
                 method.
             name (str):
@@ -870,7 +867,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_scan_run(
         self,
-        request: web_security_scanner.GetScanRunRequest = None,
+        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -880,7 +877,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Gets a ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.GetScanRunRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.GetScanRunRequest, dict]):
                 The request object. Request for the `GetScanRun` method.
             name (str):
                 Required. The resource name of the
@@ -943,7 +940,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_scan_runs(
         self,
-        request: web_security_scanner.ListScanRunsRequest = None,
+        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -954,7 +951,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         descending order of ScanRun stop time.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.ListScanRunsRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.ListScanRunsRequest, dict]):
                 The request object. Request for the `ListScanRuns`
                 method.
             parent (str):
@@ -1025,7 +1022,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def stop_scan_run(
         self,
-        request: web_security_scanner.StopScanRunRequest = None,
+        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1035,7 +1032,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Stops a ScanRun. The stopped ScanRun is returned.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.StopScanRunRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.StopScanRunRequest, dict]):
                 The request object. Request for the `StopScanRun`
                 method.
             name (str):
@@ -1099,7 +1096,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_crawled_urls(
         self,
-        request: web_security_scanner.ListCrawledUrlsRequest = None,
+        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1109,7 +1106,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""List CrawledUrls under a given ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.ListCrawledUrlsRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.ListCrawledUrlsRequest, dict]):
                 The request object. Request for the `ListCrawledUrls`
                 method.
             parent (str):
@@ -1180,7 +1177,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def get_finding(
         self,
-        request: web_security_scanner.GetFindingRequest = None,
+        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1190,7 +1187,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""Gets a Finding.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.GetFindingRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.GetFindingRequest, dict]):
                 The request object. Request for the `GetFinding` method.
             name (str):
                 Required. The resource name of the
@@ -1253,7 +1250,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_findings(
         self,
-        request: web_security_scanner.ListFindingsRequest = None,
+        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
         *,
         parent: str = None,
         filter: str = None,
@@ -1264,7 +1261,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""List Findings under a given ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.ListFindingsRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.ListFindingsRequest, dict]):
                 The request object. Request for the `ListFindings`
                 method.
             parent (str):
@@ -1345,7 +1342,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     def list_finding_type_stats(
         self,
-        request: web_security_scanner.ListFindingTypeStatsRequest = None,
+        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1355,7 +1352,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         r"""List all FindingTypeStats under a given ScanRun.
 
         Args:
-            request (google.cloud.websecurityscanner_v1beta.types.ListFindingTypeStatsRequest):
+            request (Union[google.cloud.websecurityscanner_v1beta.types.ListFindingTypeStatsRequest, dict]):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
             parent (str):
@@ -1414,6 +1411,19 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
